@@ -85,6 +85,7 @@ monthlyfunction.zoo <- function(x, FUN, na.rm=TRUE,...) {
 # Started: 25-Jul-2011                                                         #
 # Updates: 08-Aug-2011                                                         #
 #          29-May-2013 ; 03-Jun-2013                                           #
+#          23-Aug-2022                                                         #
 ################################################################################
 # 'dates'   : "numeric", "factor", "Date" indicating how to obtain the
 #             dates for correponding to the 'sname' station
@@ -124,7 +125,7 @@ monthlyfunction.data.frame <- function(x, FUN, na.rm=TRUE,
 
   # If 'dates' is a number, it indicates the index of the column of 'x' that stores the dates
   # The column with dates is then substracted form 'x' for easening the further computations
-  if ( class(dates) == "numeric" ) {
+  if ( inherits(dates, "numeric") ) {
     tmp   <- dates
     dates <- as.Date(x[, dates], format= date.fmt)
     x     <- x[-tmp]
@@ -132,12 +133,12 @@ monthlyfunction.data.frame <- function(x, FUN, na.rm=TRUE,
 
   # If 'dates' is a factor, it have to be converted into 'Date' class,
   # using the date format  specified by 'date.fmt'
-  if ( class(dates) == "factor" ) dates <- as.Date(dates, format= date.fmt)
+  if ( inherits(dates, "factor") ) dates <- as.Date(dates, format= date.fmt)
   
   # If 'dates' is already of Date class, the following line verifies that
   # the number of days in 'dates' be equal to the number of element in the
   # time series corresponding to the 'st.name' station
-  if ( ( class(dates) == "Date") & (length(dates) != nrow(x) ) )
+  if ( ( inherits(dates, "Date") ) & (length(dates) != nrow(x) ) )
      stop("Invalid argument: 'length(dates)' must be equal to 'nrow(x)'")
 
   # Transforming 'x' into a zoo object
